@@ -3,38 +3,39 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "config.h"
-
-/* defines and includes common among the jfs_fsck modules */
-#include <pwd.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include "xfsckint.h"
-#include "jfs_byteorder.h"
-#include <time.h>
+#include <config.h>
 #include <ctype.h>
-#include <stdio.h>
 #include <getopt.h>
-
-/*
- * local includes
- */
+#include <pwd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+#include <unistd.h>
+#include <sys/stat.h>
+/* defines and includes common among the jfs_fsck modules */
+#include "xfsckint.h"
+#include "xchkdsk.h"
 #include "fsck_message.h"	/* message text, all messages, in english */
-#include "jfs_version.h"	/* version number and date for utils */
+#include "jfs_byteorder.h"
 #include "jfs_unicode.h"
+#include "jfs_version.h"	/* version number and date for utils */
+#include "logform.h"
+#include "logredo.h"
+#include "message.h"
+#include "super.h"
+#include "utilsubs.h"
 
 int64_t ondev_jlog_byte_offset;
 
@@ -150,7 +151,7 @@ int report_problems_setup_repairs(void);
 int resolve_lost_and_found(void);
 int validate_fs_inodes(void);
 int verify_parms(void);
-void ask_continue();
+void ask_continue(void);
 void fsck_usage(void);
 
 /* VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV */
@@ -158,8 +159,6 @@ void fsck_usage(void);
 /* exit value */
 int exit_value = FSCK_OK;
 
-extern int Is_Device_Mounted(char *);
-
 /*****************************************************************************
  * NAME: main (jfs_fsck)
  *
@@ -229,9 +228,9 @@ int main(int argc, char **argv)
 
 	if (argc && **argv)
 		program_name = *argv;
-	else 
+	else
 		program_name = "jfs_fsck";
-		
+
 	printf("%s version %s, %s\n", program_name, VERSION, JFSUTILS_DATE);
 
 	wsp_dynstg_action = dynstg_unknown;
@@ -267,7 +266,7 @@ int main(int argc, char **argv)
 		/* initial_processing sets exit value if unsuccessful */
 		goto main_exit;
 	}
-	
+
 	if (!agg_recptr->stdout_redirected) {
 		/* begin the "running" indicator */
 		fsck_hbeat_start();
@@ -282,10 +281,10 @@ int main(int argc, char **argv)
 	    && (!agg_recptr->fsck_is_done)) {
 		/* bad block list processing only */
 		/*
-		 * this path is taken only when -f not specified, so 
-		 * fsck processing is readonly, but the clrbblks 
-		 * processing requires fsck to do some things it only 
-		 * permits when processing readwrite.  So we reset the 
+		 * this path is taken only when -f not specified, so
+		 * fsck processing is readonly, but the clrbblks
+		 * processing requires fsck to do some things it only
+		 * permits when processing readwrite.  So we reset the
 		 * switches temporarily and take care what routines we call.
 		 */
 		agg_recptr->processing_readwrite = 1;
@@ -359,14 +358,14 @@ int main(int argc, char **argv)
 	if (agg_recptr->fsck_is_done)
 		goto phases_complete;
 	rc = phase9_processing();
-	
-      phases_complete:		
+
+      phases_complete:
 	if (!agg_recptr->superblk_ok) {
 		/* superblock is bad */
 		exit_value = FSCK_ERRORS_UNCORRECTED;
 		goto close_vol;
 	}
-	
+
 	/* we at least have a superblock */
 	if ((rc == FSCK_OK) && (!(agg_recptr->fsck_is_done))) {
 		/* not fleeing an error and not making a speedy exit */
@@ -423,7 +422,7 @@ int main(int argc, char **argv)
 	Current_Time = time(NULL);
 	fsck_DateTime = localtime(&Current_Time);
 
-	sprintf(time_stamp, "%d/%d/%d %d:%02d:%02d", 
+	sprintf(time_stamp, "%d/%d/%d %d:%02d:%02d",
 		fsck_DateTime->tm_mon + 1,
 		fsck_DateTime->tm_mday, (fsck_DateTime->tm_year + 1900),
 		fsck_DateTime->tm_hour, fsck_DateTime->tm_min,
@@ -441,11 +440,11 @@ int main(int argc, char **argv)
 	if (rc == FSCK_OK) {
 		/* either all ok or nothing fatal */
 		if (agg_recptr->processing_readonly) {
-			/* remind the caller not to take 
+			/* remind the caller not to take
 			 * any messages issued too seriously
 			 */
 			fsck_send_msg(fsck_READONLY);
-			if (agg_recptr->corrections_needed || 
+			if (agg_recptr->corrections_needed ||
 			    agg_recptr->corrections_approved) {
 				fsck_send_msg(fsck_ERRORSDETECTED);
 				exit_value = FSCK_ERRORS_UNCORRECTED;
@@ -480,8 +479,8 @@ int main(int argc, char **argv)
 	} else {
 		workspace_release();
 	}
-	
-      close_vol:	
+
+      close_vol:
 	/*
 	 * Close (Unlock) the device
 	 */
@@ -497,8 +496,8 @@ int main(int argc, char **argv)
 		/* end the "running" indicator */
 		fsck_hbeat_stop();
 	}
-	
-      main_exit:	
+
+      main_exit:
 	return (exit_value);
 }
 
@@ -562,7 +561,7 @@ int check_parents_and_first_refs()
 
 		if (this_inorec->in_use)
 			goto inode_in_use;
-			
+
 		/* not in use.  A record allocated means some
 		 * directory thinks this inode is its parent
 		 */
@@ -580,7 +579,7 @@ int check_parents_and_first_refs()
 			    && (!parent_inorec->ignore_alloc_blks)
 			    && (!parent_inorec->selected_to_rls)) {
 				/*
-				 * parent inode in use and not 
+				 * parent inode in use and not
 				 * selected to release
 				 */
 				this_inorec->unxpctd_prnts = 1;
@@ -598,18 +597,18 @@ int check_parents_and_first_refs()
 		this_ext = this_inorec->ext_rec;
 		while ((this_ext != NULL) && (!done)) {
 			if ( (this_ext->ext_type == parent_extension) &&
-			     ((this_inorec->parent_inonum != ROOT_I) || 
+			     ((this_inorec->parent_inonum != ROOT_I) ||
 			      (!agg_recptr->rootdir_rebuilt)) ) {
 				/*
-				 * either this parent isn't the root or 
+				 * either this parent isn't the root or
 				 * else the root dir hasn't been rebuilt
 				 */
 				rc = get_inorecptr(aggregate_inode,
 						   alloc_ifnull,
 						   this_ext->inonum,
 						   &parent_inorec);
-				if ((parent_inorec->in_use) && 
-				    (!parent_inorec->ignore_alloc_blks) && 
+				if ((parent_inorec->in_use) &&
+				    (!parent_inorec->ignore_alloc_blks) &&
 				    (!parent_inorec->selected_to_rls)) {
 					/*
 					 * parent inode in use and
@@ -630,7 +629,7 @@ int check_parents_and_first_refs()
 			this_ext = this_ext->next;
 		}
 		goto get_next;
-		
+
       inode_in_use:
 		/* inode is in use */
 		inode_already_read = 0;
@@ -639,26 +638,26 @@ int check_parents_and_first_refs()
 			/*
 			 * there are unresolved 1st references
 			 * to multiply allocated blocks, and
-			 * blocks for this inode are reflected 
+			 * blocks for this inode are reflected
 			 * in the current workspace block map
 			 */
-			rc = inode_get(aggregate_inode, which_it, 
+			rc = inode_get(aggregate_inode, which_it,
 				       ino_idx, &inoptr);
 			if (rc == FSCK_OK) {
 				/* got the inode */
 				inode_already_read = 1;
-				rc = first_ref_check_inode(inoptr, ino_idx, 
+				rc = first_ref_check_inode(inoptr, ino_idx,
 						this_inorec, msg_info_ptr);
 			}
 		}
 		if (rc != FSCK_OK)
 			goto get_next;
-			
+
 		if ((this_inorec->parent_inonum == 0) &&
-		    (!this_inorec->unxpctd_prnts) && 
+		    (!this_inorec->unxpctd_prnts) &&
 		    (ino_idx >= FILESET_OBJECT_I)) {
 			/*
-			 * no parent recorded and not a dir with 
+			 * no parent recorded and not a dir with
 			 * unexpected parents and not a metadata inode
 			 */
 			if (agg_recptr->processing_readonly) {
@@ -675,21 +674,21 @@ int check_parents_and_first_refs()
 			 */
 			if (!inode_already_read) {
 				/* need to read the inode */
-				rc = inode_get(aggregate_inode, which_it, 
+				rc = inode_get(aggregate_inode, which_it,
 					       ino_idx, &inoptr);
 			}
 			/*
-			 * if this is a directory with 'unexpected 
-			 * parents' (aka illegal hard links) then 
-			 * the inode number which was stored in 
-			 * parent_inonum has already been stored in 
-			 * an extension record.  Save the parent 
+			 * if this is a directory with 'unexpected
+			 * parents' (aka illegal hard links) then
+			 * the inode number which was stored in
+			 * parent_inonum has already been stored in
+			 * an extension record.  Save the parent
 			 * inode number stored in the on-disk inode
 			 * for use in messages.
 			 */
 			if (rc != FSCK_OK)
 				goto get_next;
-				
+
 			if (this_inorec->unxpctd_prnts) {
 				/*
 				 * unexpected parents seen
@@ -703,13 +702,13 @@ int check_parents_and_first_refs()
 						      ino_idx);
 				}
 				/*
-				 * Otherwise, make sure a parent 
-				 * was seen and it's the one whose 
+				 * Otherwise, make sure a parent
+				 * was seen and it's the one whose
 				 * inode number is stored in the
 				 * on-disk inode.
 				 */
-			} else if ((this_inorec->parent_inonum != 0) && 
-				   (this_inorec->parent_inonum != 
+			} else if ((this_inorec->parent_inonum != 0) &&
+				   (this_inorec->parent_inonum !=
 				    inoptr->di_parent)) {
 				/*
 				 * the stored parent number is wrong
@@ -729,7 +728,7 @@ int check_parents_and_first_refs()
 			}
 		}
 
-      get_next:    	    
+      get_next:
 		if (rc == FSCK_OK) {
 			rc = get_inorecptr_next(aggregate_inode, &ino_idx,
 					        &this_inorec);
@@ -806,7 +805,7 @@ int create_lost_and_found()
 
 	if (claf_rc != FSCK_OK)
 	    goto claf_setup_exit;
-	    
+
 	/*
 	 * initialize the workspace inode record for
 	 * the new lost+found/
@@ -836,7 +835,7 @@ int create_lost_and_found()
 
 	if (claf_rc != FSCK_OK)
 		goto claf_setup_exit;
-		
+
 	/* the new lost+found inode is in the buffer */
 	ixpxd_unequal = memcmp((void *) &inoptr->di_ixpxd,
 			       (void *) &agg_recptr->ino_ixpxd, sizeof (pxd_t));
@@ -861,11 +860,11 @@ int create_lost_and_found()
 		inoptr->di_number = agg_recptr->avail_inonum;
 		inoptr->di_gen = 1;
 
-		memcpy((void *) &(inoptr->di_ixpxd), 
+		memcpy((void *) &(inoptr->di_ixpxd),
 		       (void *) &(agg_recptr->ino_ixpxd), sizeof (pxd_t));
 	}
 
-	inoptr->di_mode = (IDIRECTORY | IFJOURNAL | IFDIR | 
+	inoptr->di_mode = (IDIRECTORY | IFJOURNAL | IFDIR |
 			   IREAD | IWRITE | IEXEC);
 	inoptr->di_parent = ROOT_I;
 	/* one from root and one from self */
@@ -898,7 +897,7 @@ int create_lost_and_found()
 	claf_rc = inode_put(inoptr);
 	if (claf_rc != FSCK_OK)
 		goto claf_setup_exit;
-		
+
 	new_inorecptr->parent_inonum = ROOT_I;
 	/* The inode is correct.  After
 	 * this we'll start accumulating adjustments
@@ -929,7 +928,7 @@ int create_lost_and_found()
 		claf_rc = FSCK_CANT_EXTEND_ROOTDIR;
 		new_inorecptr->in_use = 0;
 	}
-	
+
       claf_setup_exit:
 	if (claf_rc != FSCK_OK) {
 		/* failed to create */
@@ -975,7 +974,7 @@ int final_processing()
 	 */
 	reportable_total_blocks = agg_recptr->blocks_used_in_aggregate +
 				  agg_recptr->free_blocks_in_aggregate;
-	observed_total_blocks = reportable_total_blocks - 
+	observed_total_blocks = reportable_total_blocks -
 				agg_recptr->ondev_jlog_fsblk_length -
 				agg_recptr->ondev_fscklog_fsblk_length -
 				agg_recptr->ondev_wsp_fsblk_length;
@@ -1128,11 +1127,11 @@ int report_problems_setup_repairs()
 		    (this_inorec->inlineea_off) ||
 		    (this_inorec->inline_data_err) ||
 		    (this_inorec->cant_chkea) ||
-		    (this_inorec->adj_entries) || 
-		    (this_inorec->rebuild_dirtable) || 
+		    (this_inorec->adj_entries) ||
+		    (this_inorec->rebuild_dirtable) ||
 		    ((this_inorec->unxpctd_prnts) && (!this_inorec->in_use))))
-			goto rpsr_next;    
-			
+			goto rpsr_next;
+
 		/*
 		 * a record is allocated and flagged
 		 * for some repair (other than directory
@@ -1159,7 +1158,7 @@ int report_problems_setup_repairs()
 		rc = display_paths(ino_idx, this_inorec, msg_info_ptr);
 		if (rc != FSCK_OK)
 			goto rpsr_next;
-			    
+
 		if (!this_inorec->in_use) {
 			/* not in use.  */
 			if (this_inorec->unxpctd_prnts) {
@@ -1251,8 +1250,8 @@ int report_problems_setup_repairs()
 				 * are still multiply allocated, and if so we'll mark the
 				 * aggregate dirty.
 				 */
-				if ((this_inorec->inode_type == 
-				     unrecognized_inode) || 
+				if ((this_inorec->inode_type ==
+				     unrecognized_inode) ||
 				    (this_inorec->ignore_alloc_blks))
 				{
 					agg_recptr->ag_dirty =1;
@@ -1263,13 +1262,13 @@ int report_problems_setup_repairs()
 					      msg_info_ptr->msg_inonum);
 			}
 		}
-		if ( (rc != FSCK_OK) 
-		     || this_inorec->ignore_alloc_blks 
+		if ( (rc != FSCK_OK)
+		     || this_inorec->ignore_alloc_blks
 		     || this_inorec->selected_to_rls )
 			goto rpsr_next;
-			    
+
 		/* not corrupt and */
-		/* either never selected to release or 
+		/* either never selected to release or
 		 * selected and release declined
 		 */
 		if ((rc == FSCK_OK) && (this_inorec->clr_ea_fld)) {
@@ -1422,7 +1421,6 @@ int report_problems_setup_repairs()
  */
 int initial_processing(int argc, char **argv)
 {
-	int cont = FSCK_OK;
 	int pi_rc = FSCK_OK;
 	int iml_rc = FSCK_OK;
 	int64_t fsblk_offset_bak;
@@ -1461,7 +1459,7 @@ int initial_processing(int argc, char **argv)
 				printf("\nFSCK  Device %s is currently mounted "
 				       "READ ONLY.\n", Vol_Label);
 			break;
-			
+
 		case MSG_JFS_MNT_LIST_ERROR:
 			/* setmntent failed */
 			if ((agg_recptr->parm_options[UFS_CHKDSK_DEBUG]) ||
@@ -1472,7 +1470,7 @@ int initial_processing(int argc, char **argv)
 				       "%s.  jfs_fsck will continue.\n\n",
 				       Vol_Label);
 			break;
-		
+
 		case MSG_JFS_VOLUME_IS_MOUNTED:
 			if (agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) {
 				/* read only */
@@ -1484,10 +1482,10 @@ int initial_processing(int argc, char **argv)
 				       "Running fsck on a mounted file system\n"
 				       "may cause SEVERE file system damage."
 				       "\n\n", Vol_Label);
-				ask_continue();    
+				ask_continue();
 			}
 			break;
-		
+
 		case MSG_JFS_NOT_JFS:
 			/* is not JFS */
 			printf("\n%s is mounted and the file system is not type"
@@ -1495,16 +1493,16 @@ int initial_processing(int argc, char **argv)
 			       "mounted file system\nor on a file system other "
 			       "than JFS\nmay cause SEVERE file system damage."
 			       "\n\n", Vol_Label);
-			ask_continue();    
+			ask_continue();
 			break;
-			
+
 		default:
-			ask_continue();    
+			ask_continue();
 			break;
 		}
 	}
-	
-	
+
+
 	/* the parms are good */
 	pi_rc = verify_parms();
 
@@ -1517,7 +1515,7 @@ int initial_processing(int argc, char **argv)
 		exit_value = FSCK_USAGE_ERROR;
 		goto ip_exit;
 	}
-			
+
 	/* parms are good */
 	fsck_send_msg(fsck_DRIVEID, Vol_Label);
 	pi_rc = open_volume(Vol_Label);
@@ -1525,7 +1523,7 @@ int initial_processing(int argc, char **argv)
 		/* device open failed */
 		fsck_send_msg(fsck_CNTRESUPB);
 		exit_value = FSCK_OP_ERROR;
-		goto ip_exit;		
+		goto ip_exit;
 	}
 	/* device is open */
 	agg_recptr->device_is_open = 1;
@@ -1535,7 +1533,7 @@ int initial_processing(int argc, char **argv)
 	       	exit_value = FSCK_OP_ERROR;
 		goto ip_exit;
 	}
-	
+
 	fsck_send_msg(fsck_DRIVETYPE);
 	/*
 	 * add some stuff to the agg_record which is based on
@@ -1546,13 +1544,13 @@ int initial_processing(int argc, char **argv)
 	agg_recptr->log2_blksperpg = log2shift(agg_recptr->blksperpg);
 	agg_recptr->log2_blksperag = log2shift(sb_ptr->s_agsize);
 	/*highest is the last one before the in-aggregate journal log */
-	agg_recptr->highest_valid_fset_datablk = 
+	agg_recptr->highest_valid_fset_datablk =
 	    addressPXD(&(sb_ptr->s_fsckpxd)) - 1;
 	/* lowest is the first after the secondary aggreg inode table */
 	agg_recptr->lowest_valid_fset_datablk =  addressPXD(&(sb_ptr->s_ait2)) +
 	    (INODE_EXTENT_SIZE / sb_ptr->s_bsize) + 1;
 	/*
-	 *  agg size in logical blks is 
+	 *  agg size in logical blks is
 	 *    (size in phys blks times phys blk size divided by log blk size)
 	 *  number of AGs in the aggregate:
 	 *     (agg size in log blks plus AG size in log blks minus 1)
@@ -1560,7 +1558,7 @@ int initial_processing(int argc, char **argv)
 	 */
 	agg_recptr->num_ag = ((sb_ptr->s_size * sb_ptr->s_pbsize /
 	      sb_ptr->s_bsize) + sb_ptr->s_agsize - 1) / sb_ptr->s_agsize;
-	agg_recptr->sb_agg_fsblk_length = sb_ptr->s_size * 
+	agg_recptr->sb_agg_fsblk_length = sb_ptr->s_size *
 	    sb_ptr->s_pbsize / sb_ptr->s_bsize;
 	/* length of the on-device journal log */
 	agg_recptr->ondev_jlog_fsblk_length = lengthPXD(&(sb_ptr->s_logpxd));
@@ -1585,8 +1583,8 @@ int initial_processing(int argc, char **argv)
 	agg_recptr->ondev_wsp_byte_offset =
 	    agg_recptr->ondev_wsp_fsblk_offset * sb_ptr->s_bsize;
 	/* aggregate block offset of the on-device fsck workspace */
-	agg_recptr->ondev_fscklog_fsblk_offset = 
-	    agg_recptr->ondev_wsp_fsblk_offset + 
+	agg_recptr->ondev_fscklog_fsblk_offset =
+	    agg_recptr->ondev_wsp_fsblk_offset +
 	    agg_recptr->ondev_wsp_fsblk_length;
 	/* byte offset of the on-device fsck workspace */
 	agg_recptr->ondev_fscklog_byte_offset =
@@ -1638,14 +1636,14 @@ int initial_processing(int argc, char **argv)
 	    agg_recptr->ondev_fscklog_fsblk_length +
 	    agg_recptr->ondev_jlog_fsblk_length;
 	agg_recptr->superblk_ok = 1;
-	if ((!agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) && 
+	if ((!agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) &&
 	    (agg_recptr->processing_readonly)) {
 		/* user did not specify check only but we can only
 		 * do check because we don't have write access
 		 */
 		fsck_send_msg(fsck_WRSUP);
 	}
-	
+
       ip_exit:
 	return (pi_rc);
 }
@@ -1675,7 +1673,7 @@ void parse_parms(int argc, char **argv)
 		{ "replay_journal_only", no_argument, NULL, 'J'},
 		{ NULL, 0, NULL, 0} };
 
-	while ((c = getopt_long(argc, argv, short_opts, long_opts, NULL)) 
+	while ((c = getopt_long(argc, argv, short_opts, long_opts, NULL))
 		!= EOF) {
 		switch (c) {
 		case 'r':
@@ -1733,7 +1731,7 @@ void parse_parms(int argc, char **argv)
 		 ***********************/
 			agg_recptr->parm_options_logredo_only = 1;
 			break;
-			
+
 		case 'n':
 		/***********************************
 		 * Level0 (no write access) option *
@@ -1787,13 +1785,13 @@ void parse_parms(int argc, char **argv)
 			fsck_usage();
 		}
 	}
-	
-	if (agg_recptr->parm_options_logredo_only && 
+
+	if (agg_recptr->parm_options_logredo_only &&
 	    (agg_recptr->parm_options_nologredo ||
 	     agg_recptr->parm_options[UFS_CHKDSK_LEVEL3] ||
 	     agg_recptr->parm_options[UFS_CHKDSK_LEVEL0]) ) {
 		printf("\nError: --replay_journal_only cannot be used "
-		       "with -f, -n, or --omit_journal_replay.\n");        
+		       "with -f, -n, or --omit_journal_replay.\n");
 		fsck_usage();
 	}
 
@@ -1989,35 +1987,35 @@ int phase1_processing()
 	int p1_rc = FSCK_OK;
 
 	fsck_send_msg(fsck_PHASE1);
-	
-	if ((p1_rc = establish_io_buffers()) != FSCK_OK) 
+
+	if ((p1_rc = establish_io_buffers()) != FSCK_OK)
 		goto p1_exit;
 
 	/* I/O buffers established */
 	/* establish workspace related to the aggregate */
 	if ((p1_rc = establish_agg_workspace()) != FSCK_OK)
 		goto p1_exit;
-		
+
 	/* aggregate workspace established */
-	if ((p1_rc = record_fixed_metadata()) != FSCK_OK) 
+	if ((p1_rc = record_fixed_metadata()) != FSCK_OK)
 		goto p1_exit;
-		
+
 	/* fixed metadata recorded */
 	/*
 	 * note that this processing will use the vlarge
 	 * buffer and then return it for reuse
 	 */
-	if ((p1_rc = validate_select_agg_inode_table()) != FSCK_OK) 
+	if ((p1_rc = validate_select_agg_inode_table()) != FSCK_OK)
 		goto p1_exit;
-		
+
 	/* we have an ait to work with */
 	/* establish workspace related to the fileset */
 	if ((p1_rc = establish_fs_workspace()) != FSCK_OK)
-		goto p1_exit; 
-		
+		goto p1_exit;
+
 	if ((p1_rc = record_dupchk_inode_extents()) != FSCK_OK)
 		goto p1_exit;
-		
+
 	/* fs workspace established */
 	/* claim the vlarge buffer for
 	 * validating EAs.  We do this now because
@@ -2034,7 +2032,7 @@ int phase1_processing()
 	 */
 	if ((p1_rc = validate_fs_metadata()) != FSCK_OK)
 		goto p1_exit;
-		
+
 	/* check for blocks allocated
 	 * to 2 or more metadata objects
 	 */
@@ -2043,12 +2041,12 @@ int phase1_processing()
 
 	/* validate the fileset inodes */
 	p1_rc = validate_fs_inodes();
-	
+
 	/* return the vlarge buffer for reuse */
 	agg_recptr->ea_buf_ptr = NULL;
 	agg_recptr->ea_buf_length = 0;
 	agg_recptr->vlarge_current_use = NOT_CURRENTLY_USED;
-	
+
       p1_exit:
 	if (p1_rc != FSCK_OK) {
 		agg_recptr->fsck_is_done = 1;
@@ -2148,7 +2146,7 @@ int phase3_processing()
 		 * to multiply-allocated blocks
 		 */
 
-		/* see if any first references are by 
+		/* see if any first references are by
 		 * inode extents (described in the IAGs)
 		 */
 		p3_rc = first_ref_check_inode_extents();
@@ -2255,7 +2253,7 @@ int phase6_processing()
 	if (!agg_recptr->processing_readwrite ||
 	    !agg_recptr->corrections_approved)
 		goto p6_exit;
-		
+
 	/*
 	 * we're about to write repairs.  if something stops
 	 * after we start and before we finish, we'll leave the
@@ -2285,7 +2283,7 @@ int phase6_processing()
 	}
 	if (p6_rc != FSCK_OK)
 		goto p6_setup_exit;
-		
+
 	/* nothing fatal */
 	/* Allocate space for
 	 * use during directory entry processing.
@@ -2295,7 +2293,7 @@ int phase6_processing()
 	p6_rc = directory_buffers_alloc();
 	if (p6_rc != FSCK_OK)
 		goto p6_setup_exit;
-		
+
 	/* reconnect buffers initialized */
 	p6_rc = repair_fs_inodes();
 	if (p6_rc == FSCK_OK) {
@@ -2313,8 +2311,8 @@ int phase6_processing()
 			/*
 			 * Does /lost+found/ need anything before we start?
 			 */
-			if ((agg_recptr->lsfn_ok) && 
-			    (agg_recptr->avail_inonum == 
+			if ((agg_recptr->lsfn_ok) &&
+			    (agg_recptr->avail_inonum ==
 			     agg_recptr->lsfn_inonum)) {
 				/*
 				 * /lost+found/ needs to be created
@@ -2333,16 +2331,16 @@ int phase6_processing()
 		}
 	}
 	intermed_rc = directory_buffers_release();
-	
-      p6_setup_exit:        
+
+      p6_setup_exit:
 	if (p6_rc != FSCK_OK) {
 		agg_recptr->fsck_is_done = 1;
 		exit_value = FSCK_ERRORS_UNCORRECTED;
 	} else {
 		exit_value = FSCK_CORRECTED;
 	}
-	
-      p6_exit:        
+
+      p6_exit:
 	return (p6_rc);
 }
 
@@ -2450,10 +2448,10 @@ int phase9_processing()
 	agg_recptr->logformat_rc = FSCK_OK;
 
 	if (!agg_recptr->processing_readwrite ||
-	    ((agg_recptr->logredo_rc >= 0) && 
+	    ((agg_recptr->logredo_rc >= 0) &&
 	     !agg_recptr->parm_options_nologredo))
 		goto p9_set_exit;
-		    
+
 	/* log needs reformat */
 	fsck_send_msg(fsck_PHASE9);
 	if (sb_ptr->s_flag & JFS_INLINELOG) {
@@ -2462,7 +2460,7 @@ int phase9_processing()
 #ifdef _JFS_DEBUG
 		printf("JFS fsck calling logformat \n");
 #endif
-		agg_recptr->logformat_rc = 
+		agg_recptr->logformat_rc =
 		    jfs_logform(Dev_IOPort, sb_ptr->s_bsize, sb_ptr->s_l2bsize,
 				sb_ptr->s_flag, addressPXD(&(sb_ptr->s_logpxd)),
 				lengthPXD(&(sb_ptr->s_logpxd)), NULL, NULL);
@@ -2481,7 +2479,7 @@ int phase9_processing()
 
 	if (logformat_called) {
 #ifdef _JFS_DEBUG
-		printf("JFS fsck back from logformat, rc = %ld \n", 
+		printf("JFS fsck back from logformat, rc = %ld \n",
 		       agg_recptr->logformat_rc);
 #endif
 		if (agg_recptr->logformat_rc != FSCK_OK) {
@@ -2491,7 +2489,7 @@ int phase9_processing()
 			fsck_send_msg(fsck_LOGFORMATRC, agg_recptr->logformat_rc);
 		}
 	}
-	
+
       p9_set_exit:
 	if (p9_rc != FSCK_OK) {
 		agg_recptr->fsck_is_done = 1;
@@ -2520,7 +2518,6 @@ int repair_fs_inodes()
 	struct fsck_inode_ext_record *ext_list;
 	struct fsck_inode_record *this_inorec;
 	int aggregate_inode = 0;	/* going for fileset inodes only */
-	int write_inode;
 	int which_it = 16;	/* in release 1 there is only fileset 0 */
 	struct dinode *ino_ptr;
 	struct fsck_ino_msg_info ino_msg_info;
@@ -2545,13 +2542,13 @@ int repair_fs_inodes()
 			|| (this_inorec->reconnect)
 			|| (this_inorec->link_count != 0))))
 			goto rfsi_get_next;
-				
+
 		/* flagged for repair */
-		rfsi_rc = inode_get(aggregate_inode, which_it, 
+		rfsi_rc = inode_get(aggregate_inode, which_it,
 				    ino_idx, &ino_ptr);
 		if (rfsi_rc != FSCK_OK)
 			goto rfsi_get_next;
-			
+
 		msg_info_ptr->msg_inonum = ino_idx;
 		if (this_inorec->inode_type == directory_inode) {
 			msg_info_ptr->msg_inotyp = fsck_directory;
@@ -2577,7 +2574,7 @@ int repair_fs_inodes()
 					      fsck_ref_msg(msg_info_ptr->msg_inopfx),
 					      msg_info_ptr->msg_inonum);
 			}
-			goto rfsi_inode_put;			
+			goto rfsi_inode_put;
 		}
 		/* not releasing the inode */
 		if (this_inorec->link_count != 0) {
@@ -2602,7 +2599,7 @@ int repair_fs_inodes()
 			/*
 			 * reconnect
 			 */
-			if (this_inorec->inode_type == 
+			if (this_inorec->inode_type ==
 			    directory_inode) {
 				/*
 				 * only directory inodes point back to their parent
@@ -2672,21 +2669,21 @@ int repair_fs_inodes()
 		}
 		if (!((rfsi_rc == FSCK_OK)
 		    && (this_inorec->adj_entries)))
-			goto rfsi_inode_put;    
-			
+			goto rfsi_inode_put;
+
 		/* adjust  dir entries */
 		ext_list = this_inorec->ext_rec;
 		this_inorec->ext_rec = NULL;
 		while ((ext_list != NULL) && (rfsi_rc == FSCK_OK)) {
 			this_ext = ext_list;
 			ext_list = ext_list->next;
-			if ((this_ext->ext_type == rmv_badentry_extension) || 
+			if ((this_ext->ext_type == rmv_badentry_extension) ||
 			    (this_ext->ext_type == rmv_direntry_extension)) {
 				/*
 				 * n.b. that the link count adjustment
 				 *      has already been handled.
 				 */
-				rfsi_rc = direntry_remove(ino_ptr, 
+				rfsi_rc = direntry_remove(ino_ptr,
 							  this_ext->inonum);
 				if (rfsi_rc == FSCK_OK) {
 					fsck_send_msg(fsck_INOREFRMV,
@@ -2701,14 +2698,14 @@ int repair_fs_inodes()
 				this_inorec->ext_rec = this_ext;
 			}
 		}
-		
-      rfsi_inode_put:    	    
+
+      rfsi_inode_put:
 		if (rfsi_rc == FSCK_OK) {
 			/* write it back to the device */
 			rfsi_rc = inode_put(ino_ptr);
 		}
-		
-      rfsi_get_next:    	    
+
+      rfsi_get_next:
 		if (rfsi_rc == FSCK_OK) {
 			rfsi_rc = get_inorecptr_next(aggregate_inode, &ino_idx,
 						     &this_inorec);
@@ -2988,8 +2985,8 @@ int verify_parms()
 	int mutexcl_parm_count = 0;
 
 	/*
-	 * If -f was chosen, have it override -a, -p, -r by 
-	 * turning off UFS_CHKDSK_IFDIRTY to force a check 
+	 * If -f was chosen, have it override -a, -p, -r by
+	 * turning off UFS_CHKDSK_IFDIRTY to force a check
 	 * regardless of the outcome after the log is replayed
 	 */
 	if (agg_recptr->parm_options[UFS_CHKDSK_LEVEL3]) {
@@ -3054,7 +3051,7 @@ void ask_continue()
 {
 	int cont = 0;
 	int c;
-	
+
 	printf("Do you really want to continue (y/n)? ");
 	while (1) {
 		fflush(stdout);
