@@ -3,34 +3,32 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "config.h"
+#include <config.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <sys/mount.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include "jfs_types.h"
-#include "jfs_filsys.h"
-
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include "devices.h"
-#include "debug.h"
 
+#ifdef HAVE_SYS_MOUNT_H
+#include <sys/mount.h>
+#endif
+
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <sys/ioctl.h>
 #if defined(__DragonFly__)
 #include <machine/param.h>
@@ -38,6 +36,11 @@
 #include <sys/disklabel.h>
 #endif
 
+#include "jfs_types.h"
+#include "jfs_filsys.h"
+#include "devices.h"
+#include "debug.h"
+
 #if defined(__linux__) && defined(_IO) && !defined(BLKGETSIZE64)
 #define BLKGETSIZE64 _IOR(0x12, 114, size_t)
 #endif
@@ -83,7 +86,7 @@ int ujfs_device_is_valid(FILE *device_handle, struct stat *st)
 
 	return (rc);
 }
- 
+
 /*
  * NAME: ujfs_get_dev_size
  *
@@ -115,7 +118,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 					 * read from. */
 	off_t First_Invalid_Position;	/* first invalid position we attempted
 					 * to read from/seek to. */
-	off_t Seek_Result;	/* value returned by lseek. */
+	int Seek_Result;	/* value returned by lseek. */
 	size_t Read_Result = 0;	/* value returned by read. */
 	int rc;
 	struct stat stat_data;
@@ -164,7 +167,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 		sliceinfo = &dss.dss_slices[slice];
 
 		DBG_TRACE(("ujfs_get_device_size: slice = %d\n", slice));
-		
+
 		if (sliceinfo) {
 			if (slice == WHOLE_DISK_SLICE || slice == 0) {
 				*size = (int64_t) sliceinfo->ds_size * dss.dss_secsize;
@@ -187,7 +190,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 		DBG_TRACE(("ujfs_get_device_size: size in bytes = %ld\n", *size));
 		DBG_TRACE(("ujfs_get_device_size: size in megabytes = %ld\n",
 			*size / (1024 * 1024)));
-		
+
 		return 0;
 	}
 #endif
@@ -203,7 +206,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 
 	/* Save the starting position so that we can restore it when we are
 	 * done! */
-	Starting_Position = fseeko(device, 0, SEEK_CUR);
+	Starting_Position = ftello(device);
 	if (Starting_Position < 0)
 		return ERROR_SEEK;
 
@@ -216,7 +219,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 	do {
 		/* Seek to the location we wish to test. */
 		Seek_Result = fseeko(device, Current_Position, SEEK_SET);
-		if (Seek_Result == Current_Position) {
+		if (Seek_Result == 0) {
 			/* Can we read from this location? */
 			Read_Result = fgetc(device);
 			if (Read_Result != EOF) {
@@ -230,7 +233,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 
 			}
 		}
-	} while ((Seek_Result == Last_Valid_Position) && (Read_Result == 1));
+	} while ((Seek_Result == 0) && (Read_Result == 1));
 
 	/*
 	 * We have exited the while loop, which means that Current Position is
@@ -249,7 +252,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 		 */
 		*size = 0;	/* Indicates not readable at all */
 		Seek_Result = fseeko(device, Last_Valid_Position, SEEK_SET);
-		if (Seek_Result == Last_Valid_Position) {
+		if (Seek_Result == 0) {
 			/* Can we read from this location? */
 			Read_Result = fgetc(device);
 			if (Read_Result != EOF)
@@ -279,7 +282,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 	while ((First_Invalid_Position - Last_Valid_Position) > 2) {
 		/* Seek to the location we wish to test. */
 		Seek_Result = fseeko(device, Current_Position, SEEK_SET);
-		if (Seek_Result == Current_Position) {
+		if (Seek_Result == 0) {
 			/* Can we read from this location? */
 			Read_Result = fgetc(device);
 			if (Read_Result != EOF) {
@@ -324,7 +327,7 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 
 restore:
 	/* Restore the original position. */
-	if (Starting_Position != fseeko(device, Starting_Position, SEEK_SET))
+	if (fseeko(device, Starting_Position, SEEK_SET) != 0)
 		return ERROR_SEEK;
 
 	return NO_ERROR;
@@ -359,21 +362,27 @@ restore:
  * RETURNS:
  */
 int ujfs_rw_diskblocks(FILE *dev_ptr,
-		       int64_t disk_offset, 
-		       int32_t disk_count, 
-		       void *data_buffer, 
+		       int64_t disk_offset,
+		       int32_t disk_count,
+		       void *data_buffer,
 		       int32_t mode)
 {
-	off_t Actual_Location;
+	int Seek_Result;
 	size_t Bytes_Transferred;
 	int error = NO_ERROR;
 
-	Actual_Location = fseeko(dev_ptr, disk_offset, SEEK_SET);
-	if (Actual_Location < 0) {
+	Seek_Result = fseeko(dev_ptr, disk_offset, SEEK_SET);
+	if (Seek_Result != 0) {
 		error = ERROR_SEEK;
 		goto finished;
 	}
 
+	if (disk_count == 0) {
+		fprintf(stderr, "ujfs_rw_diskblocks: disk_count is 0\n");
+		error = ERROR_INVALID_PARAMETER;
+		goto finished;
+	}
+
 	switch (mode) {
 	case GET:
 		Bytes_Transferred = fread(data_buffer, 1, disk_count, dev_ptr);
@@ -415,11 +424,9 @@ int ujfs_flush_dev(FILE *fp)
 {
 	if (fsync(fileno(fp)) == -1)
 		return errno;
-#if defined(__DragonFly__)
-	/* No explicit flushing required but we will call sync(2) */
-	sync();
-	return (0);
-#else
+#ifdef BLKFLSBUF
 	return ioctl(fileno(fp), BLKFLSBUF, 0);
+#else
+	return (0);
 #endif
 }
