@@ -1,3 +1,4 @@
+#include <config.h>
 #include "fsck_message.h"
 
 struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
@@ -5,16 +6,16 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /*   1 */ { fsck_ALLFXD, "All observed inconsistencies have been repaired.", fsck_debug},
   /*   2 */ { fsck_RIBADDATFMT, "Invalid data format detected in root directory.", fsck_quiet},
   /*   3 */ { fsck_BADBLKCTTTL, "A combination of Minimum Free Blocks and Total Usable Blocks which is invalid for the filesystem size was detected in the superblock (%s).", fsck_debug},
-  /*   4 */ { fsck_BADBLKNO, "Invalid block number(s) (%s) detected for file system object %s%s%d.", fsck_debug},
-  /*   5 */ { fsck_BADBSBLCHN, "File system object %s%s%d has a corrupt backward sibling chain.", fsck_debug},
-  /*   6 */ { fsck_BADFSBLCHN, "File system object %s%s%d has a corrupt forward sibling chain.", fsck_debug},
-  /*   7 */ { fsck_BADINOTYP, "Inode %s%d has unrecognized type.", fsck_debug},
-  /*   8 */ { fsck_BADINODXDFLDD, "File system object %s%s%d has invalid descriptor (%s).", fsck_debug},
-  /*   9 */ { fsck_BADINOLKCT, "Inode %s%d has incorrect link count.", fsck_debug},
-  /*  10 */ { fsck_BADINOREF, "Directory inode %s%d refers to a nonexistent inode %s%s (entry %u).", fsck_debug},
+  /*   4 */ { fsck_BADBLKNO, "Invalid block number(s) (%s) detected for file system object %s%s%u.", fsck_debug},
+  /*   5 */ { fsck_BADBSBLCHN, "File system object %s%s%u has a corrupt backward sibling chain.", fsck_debug},
+  /*   6 */ { fsck_BADFSBLCHN, "File system object %s%s%u has a corrupt forward sibling chain.", fsck_debug},
+  /*   7 */ { fsck_BADINOTYP, "Inode %s%u has unrecognized type.", fsck_debug},
+  /*   8 */ { fsck_BADINODXDFLDD, "File system object %s%s%u has invalid descriptor (%s).", fsck_debug},
+  /*   9 */ { fsck_BADINOLKCT, "Inode %s%u has incorrect link count.", fsck_debug},
+  /*  10 */ { fsck_BADINOREF, "Directory inode %s%u refers to a nonexistent inode %s%s (entry %u).", fsck_debug},
   /*  11 */ { fsck_ERRONLOG, "Error (%d,%d) writing to the fsck service log (%d,%lld,%ld,%ld).  Continuing.", fsck_debug},
   /*  12 */ { fsck_BOOTSECFXD, "The boot sector has been refreshed.", fsck_debug},
-  /*  13 */ { fsck_BADKEYS, "File system object %s%s%d has corrupt data (%d).", fsck_debug},
+  /*  13 */ { fsck_BADKEYS, "File system object %s%s%u has corrupt data (%d).", fsck_debug},
   /*  14 */ { fsck_BADSBOTHR, "Invalid data (%s) detected in the superblock (%s).", fsck_debug},
   /*  15 */ { fsck_BADSBAGSIZ, "Invalid allocation group size in the superblock (%s).", fsck_debug},
   /*  16 */ { fsck_BADSBBLSIZ, "Invalid filesystem block size in the superblock (%s).", fsck_debug},
@@ -34,7 +35,7 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /*  30 */ { fsck_INCONSIST2NDRY1, "Unable to replicate primary file/directory allocation structure (%s) to secondary.  FUTURE RECOVERY CAPABILITY IS COMPROMISED.", fsck_quiet},
   /*  31 */ { fsck_CHKLOGNEW, "XCHKLOG  fsck service log selected:  MOST RECENT", fsck_debug},
   /*  32 */ { fsck_LSFNCNTCRE, "MINOR: Cannot create directory lost+found in root directory.  mkdir lost+found in the root directory then run fsck with the -f parameter to reconnect lost files and/or directories.", fsck_quiet},
-  /*  33 */ { fsck_INOCANTNAME, "Fileset object %s%s%d:  No paths found.", fsck_quiet},
+  /*  33 */ { fsck_INOCANTNAME, "Fileset object %s%s%u:  No paths found.", fsck_quiet},
   /*  34 */ { fsck_INOBADREF, "The path(s) refer to an unallocated file.", fsck_quiet},
   /*  35 */ { fsck_CHKLOGOLD, "XCHKLOG  fsck service log selected:  PREVIOUS", fsck_debug},
   /*  36 */ { fsck_WILLRMVBADREF, "The path(s) refer to an unallocated file. Will remove.", fsck_quiet},
@@ -47,15 +48,15 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /*  43 */ { fsck_SEPARATOR, "\n**********************************************************", fsck_debug},
   /*  44 */ { fsck_CNTWRTSUPP, "Unable to write primary superblock.", fsck_quiet},
   /*  45 */ { fsck_ERRONAGG, "Fatal error (%d,%d) accessing the filesystem (%d,%lld,%d,%d).", fsck_debug},
-  /*  46 */ { fsck_DIRWHDLKS, "Multiple parent directories for directory %s%d.", fsck_quiet},
+  /*  46 */ { fsck_DIRWHDLKS, "Multiple parent directories for directory %s%u.", fsck_quiet},
   /*  47 */ { fsck_LOGSPECINVALID, "External journal log not supported.", fsck_debug},
-  /*  48 */ { fsck_DUPBLKREF, "Duplicate reference to %d block(s) beginning at offset %lld found in file system object %s%s%d.", fsck_debug},
-  /*  49 */ { fsck_BADMETAINOF, "File set metadata inode %s%d is corrupt.", fsck_debug},
+  /*  48 */ { fsck_DUPBLKREF, "Duplicate reference to %d block(s) beginning at offset %lld found in file system object %s%s%u.", fsck_debug},
+  /*  49 */ { fsck_BADMETAINOF, "File set metadata inode %s%u is corrupt.", fsck_debug},
   /*  50 */ { fsck_ERRONWSP, "Fatal error (%d,%d) accessing the workspace (%d,%lld,%d,%d).", fsck_debug},
   /*  51 */ { fsck_EXHDYNSTG, "Insufficient dynamic storage available for required workspace (%d,%d).  CANNOT CONTINUE", fsck_quiet},
   /*  52 */ { fsck_DEVGETCHARRC, "IOCtl(...DSK_GETDEVICEPARAMS...) returned rc = %s", fsck_debug},
   /*  53 */ { fsck_FSMNTD, "Filesystem is currently mounted.", fsck_quiet},
-  /*  54 */ { fsck_BADINOOTHR, "Invalid data (%s) detected in file system object %s%s%d.", fsck_debug},
+  /*  54 */ { fsck_BADINOOTHR, "Invalid data (%s) detected in file system object %s%s%u.", fsck_debug},
   /*  55 */ { fsck_FSSMMRY1, "Block size in bytes:  %d", fsck_quiet},
   /*  56 */ { fsck_FSSMMRY2, "Filesystem size in blocks:  %lld", fsck_quiet},
   /*  57 */ { fsck_FSSMMRY3, "Filesystem Summary:", fsck_debug},
@@ -63,25 +64,25 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /*  59 */ { fsck_FSSMMRY5, "Inode count:  %lld", fsck_debug},
   /*  60 */ { fsck_FSSMMRY6, "File count:  %lld", fsck_debug},
   /*  61 */ { fsck_FSSMMRY9, "Directory count:  %lld", fsck_debug},
-  /*  62 */ { fsck_DUPBLKREFS, "Inode %s%d has references to cross linked blocks.", fsck_debug},
+  /*  62 */ { fsck_DUPBLKREFS, "Inode %s%u has references to cross linked blocks.", fsck_debug},
   /*  63 */ { fsck_FSSMMRY7, "Block count:  %lld", fsck_debug},
   /*  64 */ { fsck_FSSMMRY8, "Free block count:  %lld", fsck_debug},
-  /*  65 */ { fsck_ILLINOREF, "Directory inode %s%d entry %s refers to an illegal inode %s%u.", fsck_debug},
+  /*  65 */ { fsck_ILLINOREF, "Directory inode %s%u entry %s refers to an illegal inode %s%u.", fsck_debug},
   /*  66 */ { fsck_XCHKLOGUSAGE, "Usage: xchklog [-f filename] [-p] [-V] <device>", fsck_debug},
-  /*  67 */ { fsck_INOCNTGETPATH, "Unable to get path for link from directory %s%d to fileset object %s%s%d.", fsck_quiet},
+  /*  67 */ { fsck_INOCNTGETPATH, "Unable to get path for link from directory %s%u to fileset object %s%s%u.", fsck_quiet},
   /*  68 */ { fsck_INOEA, "Format error in Extended Attributes Space or descriptor.", fsck_quiet},
   /*  69 */ { fsck_BADAGFELIST, "Discrepancies detected in the Free Inode Extent List for Allocation Group %s%d. (%s)", fsck_debug},
   /*  70 */ { fsck_MNCNTRCNCTINOF, "MINOR: Unable to reconnect file inode %c%u.  Continuing.", fsck_debug},
-  /*  71 */ { fsck_INCINOREF, "Directory %s%d entry \"..\" refers to an incorrect parent directory (%s%s).", fsck_quiet},
-  /*  72 */ { fsck_INCINOREFCRCT, "Directory inode %s%d entry \"..\" reference to incorrect inode corrected.", fsck_debug},
-  /*  73 */ { fsck_INOCLRD, "Storage allocated to inode %s%d has been cleared.", fsck_debug},
-  /*  74 */ { fsck_INOEACLRD, "Storage allocated to extended attributes for inode %s%d has been cleared.", fsck_debug},
+  /*  71 */ { fsck_INCINOREF, "Directory %s%u entry \"..\" refers to an incorrect parent directory (%s%u).", fsck_quiet},
+  /*  72 */ { fsck_INCINOREFCRCT, "Directory inode %s%u entry \"..\" reference to incorrect inode corrected.", fsck_debug},
+  /*  73 */ { fsck_INOCLRD, "Storage allocated to inode %s%u has been cleared.", fsck_debug},
+  /*  74 */ { fsck_INOEACLRD, "Storage allocated to extended attributes for inode %s%u has been cleared.", fsck_debug},
   /*  75 */ { fsck_INOINLSFNF, "File inode %c%u has been reconnected to /lost+found/.", fsck_debug},
-  /*  76 */ { fsck_INOLKCTFXD, "Link count for inode %s%d has been adjusted/corrected.", fsck_debug},
+  /*  76 */ { fsck_INOLKCTFXD, "Link count for inode %s%u has been adjusted/corrected.", fsck_debug},
   /*  77 */ { fsck_DEVLOCKRC, "IOCtl(...DSK_LOCKDRIVE...) returned rc = %s", fsck_debug},
-  /*  78 */ { fsck_INONOPATHS, "No paths were found for inode %s%d.", fsck_debug},
-  /*  79 */ { fsck_INOPATHOK, "File system object %s%s%d is linked as: %s", fsck_quiet},
-  /*  80 */ { fsck_INOREFRMV, "Directory inode %s%d entry reference to inode %s%d removed.", fsck_debug},
+  /*  78 */ { fsck_INONOPATHS, "No paths were found for inode %s%u.", fsck_debug},
+  /*  79 */ { fsck_INOPATHOK, "File system object %s%s%u is linked as: %s", fsck_quiet},
+  /*  80 */ { fsck_INOREFRMV, "Directory inode %s%u entry reference to inode %s%u removed.", fsck_debug},
   /*  81 */ { fsck_BADSBFWSL, "Invalid fwsp length detected in the superblock (%s).", fsck_debug},
   /*  82 */ { fsck_BADSBFWSA, "Invalid fwsp address detected in the superblock (%s).", fsck_debug},
   /*  83 */ { fsck_DEVOPENRDRC, "Open(...READONLY...) returned rc = %d", fsck_debug},
@@ -89,7 +90,7 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /*  85 */ { fsck_LOGREDOFAIL, "logredo failed (rc=%d).  fsck continuing.", fsck_quiet},
   /*  86 */ { fsck_LOGREDORC, "logredo returned rc = %d", fsck_debug},
   /*  87 */ { fsck_LSFNNOTDIR, "Unable to create a lost+found directory in root  because root already contains a non-directory object named lost+found.  Rename the existing lost+found object in root, mkdir lost+found in the root directory, then run fsck with the -f parameter to reconnect lost files and/or directories.", fsck_quiet},
-  /*  88 */ { fsck_MNTFSYS2, "Checking a mounted filesystem does not produce dependable results.", fsck_quiet},
+  /*  88 */ { fsck_MNTFSYS2, "WARNING: Checking a mounted filesystem does not produce dependable results.", fsck_quiet},
   /*  89 */ { fsck_MODIFIED, "**** Filesystem was modified. ****", fsck_debug},
   /*  90 */ { fsck_DEVREDETERMRC, "ujfs_redeterminemedia() returned rc = %s", fsck_debug},
   /*  91 */ { fsck_MRKSBDONE, "Superblock marked.", fsck_debug},
@@ -113,8 +114,8 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 109 */ { fsck_WILLRMVBADENTRY, "Directory has entry for unallocated file %s%u. Will remove.", fsck_quiet},
   /* 110 */ { fsck_ERRONAITRD, "FATAL ERROR (%d,%d) ON READ Aggregate Inode Table (%d) first extent.", fsck_debug},
   /* 111 */ { fsck_WILLCLEAREA, "Format error in Extended Attributes Space or descriptor. Will clear.", fsck_quiet},
-  /* 112 */ { fsck_BADIAMIAGPXDL, "The extent descriptor for inodes %d through %d is invalid.  (Inode Allocation Map %s%s, Inode Allocation Group %d, Extent Index %d).", fsck_debug},
-  /* 113 */ { fsck_EAFORMATBAD, "Extended attributes for file set object %s%s%d have an invalid format.", fsck_debug},
+  /* 112 */ { fsck_BADIAMIAGPXDL, "The extent descriptor for inodes %d through %d is invalid.  (Inode Allocation Map %s%d, Inode Allocation Group %d, Extent Index %d).", fsck_debug},
+  /* 113 */ { fsck_EAFORMATBAD, "Extended attributes for file set object %s%s%u have an invalid format.", fsck_debug},
   /* 114 */ { fsck_REPAIRSINPROGRESS, "Superblock marked dirty because repairs are about to be written.", fsck_debug},
   /* 115 */ { fsck_PRMMUTEXCLLEVELS, "Mutually exclusive 'check READ ONLY' and 'fix file system' options specified.", fsck_quiet},
   /* 116 */ { avail_116, "*undefined*", fsck_quiet},
@@ -145,30 +146,30 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 141 */ { fsck_BADINOCLAIMSDUPSF, "File claims cross linked block(s).", fsck_quiet},
   /* 142 */ { fsck_BADINODATAFORMAT, "cannot repair the data format error(s) in this file.", fsck_quiet},
   /* 143 */ { fsck_BADINOFORMAT, "cannot repair the format error(s) in this file.", fsck_quiet},
-  /* 144 */ { fsck_CANTREPAIRINO, "cannot repair %s%s%d.", fsck_quiet},
+  /* 144 */ { fsck_CANTREPAIRINO, "cannot repair %s%s%u.", fsck_quiet},
   /* 145 */ { fsck_DRIVEID, "The current device is:  %s", fsck_quiet},
   /* 146 */ { fsck_DRIVETYPE, "The type of file system for the device is JFS.", fsck_debug},
-  /* 147 */ { fsck_WILLRELEASEINO, "cannot repair %s%s%d.  Will release.", fsck_quiet},
+  /* 147 */ { fsck_WILLRELEASEINO, "cannot repair %s%s%u.  Will release.", fsck_quiet},
   /* 148 */ { fsck_SBOKS, "Secondary superblock is valid.", fsck_debug},
   /* 149 */ { fsck_WRSUP, "Unable to open for write access.  Proceeding in read-only mode.", fsck_quiet},
-  /* 150 */ { fsck_WILLFIXDIRWHDLKS, "Multiple parent directories for directory %s%d.  Will correct.", fsck_quiet},
-  /* 151 */ { fsck_WILLFIXINCREF, "Directory %s%d entry \"..\" refers to an incorrect parent directory (%s%d). Will correct.", fsck_quiet},
+  /* 150 */ { fsck_WILLFIXDIRWHDLKS, "Multiple parent directories for directory %s%u.  Will correct.", fsck_quiet},
+  /* 151 */ { fsck_WILLFIXINCREF, "Directory %s%u entry \"..\" refers to an incorrect parent directory (%s%u). Will correct.", fsck_quiet},
   /* 152 */ { fsck_XTRABLKS, "%lld unexpected blocks detected.", fsck_quiet},
   /* 153 */ { fsck_RODIRSWHLKS, "Directories with illegal hard links have been detected.", fsck_quiet},
   /* 154 */ { fsck_ROINCINOREFS, "Directory entries (entries \"..\") referring to incorrect parent directories have been detected.", fsck_quiet},
   /* 155 */ { fsck_ROUALINOREFS, "Directory entries for unallocated files have been detected.", fsck_quiet},
   /* 156 */ { fsck_CNTWRTSUPS, "Unable to write secondary superblock.", fsck_quiet},
   /* 157 */ { fsck_WILLFIXLINKCTS, "Incorrect link counts have been detected. Will correct.", fsck_quiet},
-  /* 158 */ { fsck_INOINLINECONFLICT, "File set object %s%s%d has inline data conflict (type %d).", fsck_debug},
+  /* 158 */ { fsck_INOINLINECONFLICT, "File set object %s%s%u has inline data conflict (type %d).", fsck_debug},
   /* 159 */ { fsck_DUPBLKMDREFS, "Duplicate block references have been detected in Metadata.  CANNOT CONTINUE.", fsck_quiet},
   /* 160 */ { fsck_DUPBLKMDREF, "Multiple metadata references to %d blocks beginning at offset %lld have been detected.", fsck_debug},
-  /* 161 */ { fsck_BADDINOFREELIST1, "Directory inode %s%d has a node with empty freelist and nonzero freecount.", fsck_debug},
+  /* 161 */ { fsck_BADDINOFREELIST1, "Directory inode %s%u has a node with empty freelist and nonzero freecount.", fsck_debug},
   /* 162 */ { fsck_CANTREADEAITEXT1, "Unable to read entire first extent of AIT (%s).", fsck_debug},
   /* 163 */ { fsck_CANTREADAITEXT1, "Unable to read first extent of AIT (%s).", fsck_debug},
   /* 164 */ { fsck_URCVUNLCK, "Unrecoverable error during UNLOCK processing.", fsck_quiet},
   /* 165 */ { fsck_URCVCLOSE, "Unrecoverable error during CLOSE processing.", fsck_quiet},
   /* 166 */ { fsck_RICRRCTDREF, "The root directory reference (entry \"..\") has been corrected.", fsck_debug},
-  /* 167 */ { fsck_INOPATHCRCT, "%s appears to be the correct path for directory %s%d.", fsck_quiet},
+  /* 167 */ { fsck_INOPATHCRCT, "%s appears to be the correct path for directory %s%u.", fsck_quiet},
   /* 168 */ { fsck_RODIRWHLKS, "Directory inode %s%u has illegal hard links.", fsck_debug},
   /* 169 */ { fsck_ROINCINOREF, "Directory inode %s%u refers (entry \"..\") to an incorrect inode (%s%u).", fsck_debug},
   /* 170 */ { fsck_ROUALINOREF, "One or more directory entry found for unallocated inode %s%u.", fsck_debug},
@@ -180,7 +181,7 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 176 */ { fsck_XCHKLOGNEW, "XCHKLOG  Most recent fsck service log extracted into:  %s", fsck_debug},
   /* 177 */ { fsck_XCHKLOGOLD, "XCHKLOG  Prior fsck service log extracted into:  %s", fsck_debug},
   /* 178 */ { fsck_XCHKLOGOPNFAIL, "XCHKLOG  Can't open output file:  %s", fsck_debug},
-  /* 179 */ { fsck_BADINOSTAMP, "Invalid stamp detected in file system object %s%s%d.", fsck_debug},
+  /* 179 */ { fsck_BADINOSTAMP, "Invalid stamp detected in file system object %s%s%u.", fsck_debug},
   /* 180 */ { fsck_ROUNCONNIOS, "Files and/or directories not connected to the root directory tree have been detected.", fsck_quiet},
   /* 181 */ { fsck_WILLFIXROUALINOREFS, "Directory entries for unallocated files have been detected.  Will remove.", fsck_quiet},
   /* 182 */ { fsck_WILLFIXROUNCONNIOS, "Files and/or directories not connected to the root directory tree have been detected.  Will reconnect.", fsck_quiet},
@@ -193,20 +194,20 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 189 */ { fsck_AGGDRTYNOTCLN, "Filesystem is dirty but is marked clean.  In its present state,\nthe results of accessing %s (except by this utility) are undefined.", fsck_quiet},
   /* 190 */ { fsck_AGGMRKDCLN, "Filesystem has been marked clean.", fsck_debug},
   /* 191 */ { fsck_AGGMRKDDRTY, "Filesystem has been marked dirty because it contains critical errors.  Filesystem may be unrecoverable.", fsck_quiet},
-  /* 192 */ { fsck_BADINOMTNODE, "File system object %s%s%d has an illegal empty node.", fsck_debug},
-  /* 193 */ { fsck_BADINOODDINTRNEXT, "File system object %s%s%d -- extent at offset %lld has an invalid size (%d).", fsck_debug},
-  /* 194 */ { fsck_BADINOFRONTGAP, "Dense file (inode %s%d) begins with an unallocated section.", fsck_debug},
-  /* 195 */ { fsck_BADINOINTERNGAP, "Dense file (inode %s%d) has an unallocated section after offset %lld.", fsck_debug},
+  /* 192 */ { fsck_BADINOMTNODE, "File system object %s%s%u has an illegal empty node.", fsck_debug},
+  /* 193 */ { fsck_BADINOODDINTRNEXT, "File system object %s%s%u -- extent at offset %lld has an invalid size (%d).", fsck_debug},
+  /* 194 */ { fsck_BADINOFRONTGAP, "Dense file (inode %s%u) begins with an unallocated section.", fsck_debug},
+  /* 195 */ { fsck_BADINOINTERNGAP, "Dense file (inode %s%u) has an unallocated section after offset %lld.", fsck_debug},
   /* 196 */ { fsck_BADAGFELIST1, "The Free Inode Extent List is inconsistent for Allocation Group %s%d.", fsck_debug},
   /* 197 */ { fsck_BADAGFILIST, "Discrepancies detected in the Free Inode List for Allocation Group %s%d. (%s)", fsck_debug},
   /* 198 */ { fsck_BADAGFILIST1, "The Free Inode List is inconsistent for Allocation Group %s%d.", fsck_debug},
   /* 199 */ { fsck_BADIAGAG, "Inode Allocation Group %s%d has an invalid Allocation Group (%lld).", fsck_debug},
   /* 200 */ { fsck_BADDIRENTRY, "Directory has an entry for an unallocated file %s%u.", fsck_quiet},
-  /* 201 */ { fsck_BADDINONODESIZ, "Directory inode %s%d has a node with incorrect size.", fsck_debug},
-  /* 202 */ { fsck_BADDINOODDNODESIZ, "Directory inode %s%d has a node with invalid size.", fsck_debug},
-  /* 203 */ { fsck_BADDINOFREELIST4, "Directory inode %s%d has a node with an invalid freelist.", fsck_debug},
-  /* 204 */ { fsck_BADDINOFREELIST2, "Directory inode %s%d has a node with an incorrect freecount.", fsck_debug},
-  /* 205 */ { fsck_BADDINOFREELIST3, "Directory inode %s%d has a node with an incorrect freelist.", fsck_debug},
+  /* 201 */ { fsck_BADDINONODESIZ, "Directory inode %s%u has a node with incorrect size.", fsck_debug},
+  /* 202 */ { fsck_BADDINOODDNODESIZ, "Directory inode %s%u has a node with invalid size.", fsck_debug},
+  /* 203 */ { fsck_BADDINOFREELIST4, "Directory inode %s%u has a node with an invalid freelist.", fsck_debug},
+  /* 204 */ { fsck_BADDINOFREELIST2, "Directory inode %s%u has a node with an incorrect freecount.", fsck_debug},
+  /* 205 */ { fsck_BADDINOFREELIST3, "Directory inode %s%u has a node with an incorrect freelist.", fsck_debug},
   /* 206 */ { fsck_BADIAGAGSTRT, "Inode Allocation Group %s%d has an invalid AG Start.", fsck_debug},
   /* 207 */ { fsck_BADIAGFIES, "Inode Allocation Group %s%d has an invalid Free Extent Summary.", fsck_debug},
   /* 208 */ { fsck_BADIAGFIS, "Inode Allocation Group %d%d has an invalid Free Inode Summary.", fsck_debug},
@@ -275,7 +276,7 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 271 */ { fsck_BADINOCLAIMSDUPSD, "Directory claims cross linked block(s).", fsck_quiet},
   /* 272 */ { fsck_BADINOCLAIMSDUPSO, "File system object claims cross linked block(s).", fsck_quiet},
   /* 273 */ { fsck_SPARSEFILSYS, "File system is formatted for sparse files.", fsck_quiet},
-  /* 274 */ { fsck_INCDASDUSEDCRCT, "Directory inode %s%d incorrect DASD used value corrected.", fsck_debug},
+  /* 274 */ { fsck_INCDASDUSEDCRCT, "Directory inode %s%u incorrect DASD used value corrected.", fsck_debug},
   /* 275 */ { fsck_INOSINLSFNDS, "%u directories reconnected to /lost+found/.", fsck_quiet},
   /* 276 */ { fsck_INOSINLSFNF, "%u file reconnected to /lost+found/.", fsck_quiet},
   /* 277 */ { fsck_INOSINLSFNFS, "%u files reconnected to /lost+found/.", fsck_quiet},
@@ -300,7 +301,7 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 296 */ { fsck_ERRORSINAITS, "Errors detected in the Secondary File/Directory Allocation Table.", fsck_quiet},
   /* 297 */ { fsck_CNTRESUPS, "Unable to read secondary superblock.", fsck_debug},
   /* 298 */ { fsck_DI_TABLE, "Errors detected in Directory Index Table.", fsck_quiet},
-  /* 299 */ { fsck_DI_TABLE_FXD, "Directory Index Table for inode %s%d has been reset.", fsck_debug},
+  /* 299 */ { fsck_DI_TABLE_FXD, "Directory Index Table for inode %s%u has been reset.", fsck_debug},
   /* 300 */ { fsck_WILLFIX_DI_TABLE, "Errors detected in Directory Index Table. Will Fix.", fsck_quiet},
   /* 301 */ { fsck_MNCNTRCNCTINOSDS, "MINOR: Unable to reconnect %u directories.  Continuing.", fsck_quiet},
   /* 302 */ { fsck_MNCNTRCNCTINOSF, "MINOR: Unable to reconnect %u file.  Continuing.", fsck_quiet},
@@ -358,19 +359,19 @@ struct fsck_message msg_defs[fsck_highest_msgid_defined+1] = {
   /* 354 */ { fsck_DOSEXECPGMRC, "DosExecPgm(...clrbblks...) rc = %s", fsck_debug},
   /* 355 */ { fsck_DEVOPENRDWRSRC, "Open(...OPEN_SHARE_DENYNONE|OPEN_ACCESS_READWRITE...) returned rc = %s", fsck_debug},
   /* 356 */ { fsck_CLRBBOPENFAILED, "Device unavailable or locked by another process.   CANNOT CONTINUE.", fsck_quiet},
-  /* 357 */ { fsck_BADINONODESELF, "File system object %s%s%d has a node with an invalid self field.", fsck_debug},
-  /* 358 */ { fsck_INOPATHBAD, "File system object %s%s%d is illegally linked as: %s", fsck_quiet},
+  /* 357 */ { fsck_BADINONODESELF, "File system object %s%s%u has a node with an invalid self field.", fsck_debug},
+  /* 358 */ { fsck_INOPATHBAD, "File system object %s%s%u is illegally linked as: %s", fsck_quiet},
   /* 359 */ { fsck_CANTRECONINSUFSTG, "Insufficient storage (%d) available to continue reconnecting lost files and/or directories. Continuing.", fsck_quiet},
   /* 360 */ { fsck_INOACL, "Format error in Access Control List space or descriptor.", fsck_quiet},
   /* 361 */ { fsck_WILLCLEARACL, "Format error in Access Control List space or descriptor. Will clear.", fsck_quiet},
-  /* 362 */ { fsck_INOACLCLRD, "Storage allocated to Access Control List for inode %s%d has been cleared.", fsck_debug},
+  /* 362 */ { fsck_INOACLCLRD, "Storage allocated to Access Control List for inode %s%u has been cleared.", fsck_debug},
   /* 363 */ { fsck_STDSUMMARY4A, "%9lld kilobytes in access control lists", fsck_debug},
   /* 364 */ { fsck_EXHFILSYSSTG, "File system is full or too fragmented to allocated requested %d blocks.", fsck_debug},
   /* 365 */ { fsck_INOMINOR, "Minor format error detected.", fsck_quiet},
-  /* 366 */ { fsck_INOMINORFXD, "Minor format error in inode %s%d has been corrected.", fsck_debug},
+  /* 366 */ { fsck_INOMINORFXD, "Minor format error in inode %s%u has been corrected.", fsck_debug},
   /* 367 */ { fsck_WILLFIXINOMINOR, "Minor format error detected. Will fix.", fsck_quiet},
-  /* 368 */ { fsck_BADINODXDFLDL, "File system object %s%s%d has invalid length in descriptor (%s).", fsck_debug},
-  /* 369 */ { fsck_BADINODXDFLDO, "File system object %s%s%d has invalid offset in descriptor (%s).", fsck_debug},
+  /* 368 */ { fsck_BADINODXDFLDL, "File system object %s%s%u has invalid length in descriptor (%s).", fsck_debug},
+  /* 369 */ { fsck_BADINODXDFLDO, "File system object %s%s%u has invalid offset in descriptor (%s).", fsck_debug},
   /* 370 */ { fsck_READONLY, "File system checked READ ONLY.", fsck_quiet},
   /* 371 */ { fsck_PRMBADDEVICE	, "Device does not exist.", fsck_quiet},
   /* 372 */ { fsck_PRMNODEVICE	, "No device given.", fsck_quiet},
