@@ -3,22 +3,23 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "jfs_endian.h"
+#include <config.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include "jfs_endian.h"
 #include "devices.h"
 
 #if __BYTE_ORDER == __BIG_ENDIAN
@@ -67,7 +68,6 @@ void ujfs_swap_dbmap(struct dbmap *dbm_t)
  */
 void ujfs_swap_dinode(struct dinode *di, int32_t mode, uint32_t sb_flag)
 {
-	int i;
 	dtpage_t *p;
 
 	/* struct dinode in jfs_dinode.h */
@@ -476,8 +476,6 @@ void ujfs_swap_logpage(struct logpage *lpage_t, uint8_t numpages)
  */
 void ujfs_swap_logsuper(struct logsuper *lsup_t)
 {
-	int i;
-
 	/* struct logsuper in jfs_logmgr.h */
 
 	lsup_t->magic = __le32_to_cpu(lsup_t->magic);
