@@ -3,19 +3,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "jfs_types.h"
+#include <config.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <string.h>
@@ -23,6 +23,8 @@
 #include <unistd.h>
 #include <dirent.h>
 #include <errno.h>
+
+#include "jfs_types.h"
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
@@ -121,7 +123,7 @@ FILE * walk_dir(char *path, uuid_t uuid, int is_label, int is_log, int *in_use)
 		while ((lv_ent = readdir(lv_dir))) {
 			path[path_len] = 0;
 			if (!strcmp(lv_ent->d_name, ".") ||
-			    !strcmp(lv_ent->d_name, "..") || 
+			    !strcmp(lv_ent->d_name, "..") ||
 			    !strcmp(lv_ent->d_name, ".nodes"))
 				continue;
 			strcat(path, lv_ent->d_name);
@@ -133,7 +135,7 @@ FILE * walk_dir(char *path, uuid_t uuid, int is_label, int is_log, int *in_use)
 			else if (S_ISDIR(st.st_mode))
 				fp = walk_dir(path, uuid, is_label, is_log,
 					      in_use);
-			else 
+			else
 				continue;
 			if (fp) {
 				closedir(lv_dir);
