@@ -3,19 +3,20 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 #define _GNU_SOURCE	/* FOR O_DIRECT */
+#include <config.h>
 #include "jfs_types.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -197,8 +198,8 @@ static int initdmap(FILE *dev_ptr, int64_t blkno, int64_t nblocks,
 static int initctl(FILE *dev_ptr,
 		   int64_t blkno,
 		   int64_t nblocks,
-		   int level, 
-		   int8_t * treemax, 
+		   int level,
+		   int8_t * treemax,
 		   int64_t * start)
 {
 	int index, rc = 0, l2cblks, nchild;
@@ -242,11 +243,11 @@ static int initctl(FILE *dev_ptr,
 		nb = MIN(cblks, nblocks);
 
 		/*
-		 * If this is a level 0 dmapctl, initialize the dmap for the 
-		 * block range (i.e. blkno thru blkno+nb-1).  Otherwise, 
-		 * initialize the lower level dmapctl for this block range.  
-		 * In either case, the pointer to the leaf covering this block 
-		 * range is passed down and will be set to the length of the 
+		 * If this is a level 0 dmapctl, initialize the dmap for the
+		 * block range (i.e. blkno thru blkno+nb-1).  Otherwise,
+		 * initialize the lower level dmapctl for this block range.
+		 * In either case, the pointer to the leaf covering this block
+		 * range is passed down and will be set to the length of the
 		 * maximum free string of blocks found at the lower level.
 		 */
 		if (level == 0) {
@@ -260,7 +261,7 @@ static int initctl(FILE *dev_ptr,
 
 	/*
 	 * Initialize the leaves for this dmapctl that were not covered by the
-	 * specified input block range (i.e. the leaves have no low level 
+	 * specified input block range (i.e. the leaves have no low level
 	 * dmapctl or dmap.
 	 */
 	for (; index < LPERCTL; index++) {
@@ -284,7 +285,7 @@ static int initctl(FILE *dev_ptr,
 	free(dcp);
 
 	/*
-	 * Set the treemax return value with the maximum free described by 
+	 * Set the treemax return value with the maximum free described by
 	 * this dmapctl.
 	 */
 	*treemax = max;
@@ -554,7 +555,7 @@ int markit(int block, unsigned flag)
 	int64_t num_blocks_left, nb;
 
 	/*
-	 * Keep track of the last allocated block to be filled into block map 
+	 * Keep track of the last allocated block to be filled into block map
 	 * inode.  Don't update last allocated for bad blocks.
 	 */
 	if (block > last_allocated && !(flag & BADBLOCK)) {
@@ -642,7 +643,7 @@ int write_block_map(FILE *dev_ptr, int64_t number_of_blocks, int aggr_block_size
 
 	/*
 	 * At this point all of the dmaps have been initialized except for their
-	 * trees.  Now we need to build the other levels of the map and adjust 
+	 * trees.  Now we need to build the other levels of the map and adjust
 	 * the tree for each of the dmaps.
 	 */
 	cur_dmap_index = 0;
@@ -662,7 +663,7 @@ int write_block_map(FILE *dev_ptr, int64_t number_of_blocks, int aggr_block_size
  *      xaddr   - On return, filled in with starting block number of allocated
  *                blocks
  *
- * NOTES:	
+ * NOTES:
  *	This function is only called when adding blocks to the Bad Block Inode
  *	required a page for an xtree node.  LVM Bad Block processing must
  *	be in effect during this allocation.  This will not be the case if format
@@ -688,8 +689,8 @@ static int dbAlloc(FILE *dev_ptr, int64_t xlen, int64_t * xaddr)
 	 * Start looking at last block allocated for a contiguous extent of xlen
 	 * blocks.  Since we may have bad blocks intermixed we can't just
 	 * take blocks starting at the last block allocated.  However,
-	 * last_allocated won't be updated with bad blocks, so it will be the 
-	 * start of the real last place to start looking.  Once found, mark them 
+	 * last_allocated won't be updated with bad blocks, so it will be the
+	 * start of the real last place to start looking.  Once found, mark them
 	 * allocated and return the starting address in xaddr
 	 */
 	l2nb = log2shift(xlen);
@@ -698,9 +699,9 @@ static int dbAlloc(FILE *dev_ptr, int64_t xlen, int64_t * xaddr)
 	     word = (last_allocated & (BPERDMAP - 1)) >> L2DBWORD;
 	     page < sz_block_map_array; page++, word = 0) {
 		/*
-		 * Determine if this dmap page has been allocated yet; if not we 
-		 * can take the first blocks from it for our allocation since we 
-		 * know all the blocks in it are free.  (markit will handle 
+		 * Determine if this dmap page has been allocated yet; if not we
+		 * can take the first blocks from it for our allocation since we
+		 * know all the blocks in it are free.  (markit will handle
 		 * allocating the page for us, so we don't have to do that here.)
 		 */
 		if (block_map_array[page] == NULL) {
@@ -717,17 +718,17 @@ static int dbAlloc(FILE *dev_ptr, int64_t xlen, int64_t * xaddr)
 		}
 
 		/*
-		 * We have a dmap page which has had allocations before, we need 
-		 * to check for free blocks starting with <word> to the end of 
-		 * this dmap page.  If we don't find it in this page we will go 
+		 * We have a dmap page which has had allocations before, we need
+		 * to check for free blocks starting with <word> to the end of
+		 * this dmap page.  If we don't find it in this page we will go
 		 * on to the next page.
 		 */
 		p1 = block_map_array[page];
 
 		for (; word < LPERDMAP; word++) {
 			/*
-			 * Determine if the leaf describes sufficient free space.  
-			 * Since we have not yet completed the block map 
+			 * Determine if the leaf describes sufficient free space.
+			 * Since we have not yet completed the block map
 			 * initialization we will have to compute this on the-fly.
 			 */
 			leafw = ujfs_maxbuddy((char *) &p1->wmap[word]);
@@ -735,7 +736,7 @@ static int dbAlloc(FILE *dev_ptr, int64_t xlen, int64_t * xaddr)
 				continue;
 
 			/*
-			 * We know this word has sufficient free space, find it 
+			 * We know this word has sufficient free space, find it
 			 * and allocate it
 			 */
 			*xaddr = (page << L2BPERDMAP) + (word << L2DBWORD);
@@ -921,7 +922,7 @@ static int xtSplitPage(struct dinode *ip,
 		return rc;
 
 	/*
-	 * We are now done with the xpage as-is.  We can now re-use this buffer 
+	 * We are now done with the xpage as-is.  We can now re-use this buffer
 	 * for our new buffer.
 	 */
 	newpage = xpage->page;
@@ -988,7 +989,7 @@ static int xtAppend(FILE *dev_ptr,
 	/* insert entry for new extent */
 	if (index == cur_page->header.maxentry) {
 		/*
-		 * There is not room in this page to add the entry; Need to 
+		 * There is not room in this page to add the entry; Need to
 		 * create a new page
 		 */
 		if (cur_page->header.flag & BT_ROOT) {
@@ -997,7 +998,7 @@ static int xtAppend(FILE *dev_ptr,
 					 blkno);
 		} else {
 			/*
-			 * Non-root page: add new page at this level, xtSplitPage() 
+			 * Non-root page: add new page at this level, xtSplitPage()
 			 * calls xtAppend again to propogate up the new page entry
 			 */
 			rc = xtSplitPage(di, xpage, offset, nblocks, blkno,
@@ -1085,7 +1086,8 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 	int rc = 0;
 	int error;
 	void *buffer = NULL;
-	int bufsize = PSIZE << 5, nbufblks;
+	int bufsize = PSIZE << 5;
+	int nbufblks;
 	int64_t nblocks, nb;
 	int64_t blkno, thisblk;
 	int percent, section, index;
@@ -1112,9 +1114,9 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 	       posix_memalign(&buffer, aggr_block_size, bufsize))
 #else
 #ifdef HAVE_MEMALIGN
-			(buffer = memalign(aggr_block_size, bufsize)))
+			(buffer = memalign(aggr_block_size, bufsize)) == NULL)
 #else
-			(buffer = valloc(bufsize)))
+			(buffer = valloc(bufsize)) == NULL)
 #endif
 #endif
 		bufsize >>= 1;
@@ -1126,14 +1128,16 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 	memset(buffer, 0, bufsize);
 	nbufblks = bufsize / aggr_block_size;
 
+#ifdef O_DIRECT
 	/*
 	 * Must do direct-io to avoid the page cache
 	 */
 	flags = fcntl(fileno(dev_ptr), F_GETFL);
 	fcntl(fileno(dev_ptr), F_SETFL, flags | O_DIRECT);
+#endif
 
 	/*
-	 * Starting from the last allocated block to the end of the aggregate 
+	 * Starting from the last allocated block to the end of the aggregate
 	 * write the empty buffer to disk.
 	 */
 	blkno = last_allocated + 1;
@@ -1167,9 +1171,9 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 
 		if (error != 0) {
 			/*
-			 * At least one of the blocks we just tried to write was 
-			 * bad.  To narrow down the problem, we will write each 
-			 * block individually and add any bad ones to our bad 
+			 * At least one of the blocks we just tried to write was
+			 * bad.  To narrow down the problem, we will write each
+			 * block individually and add any bad ones to our bad
 			 * block inode.
 			 */
 			for (thisblk = blkno; thisblk < blkno + nb; thisblk++) {
@@ -1181,7 +1185,7 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 						       PUT);
 
 				/*
-				 * most devices don't report an error on write, 
+				 * most devices don't report an error on write,
 				 * so we have to verify explicitly to be sure.
 				 */
 				if (error == 0) {
@@ -1195,7 +1199,9 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 
 				if (error != 0) {
 					/* add_bad_block may do unaligned I/O */
+#ifdef O_DIRECT
 					fcntl(fileno(dev_ptr), F_SETFL, flags);
+#endif
 
 					/* Add this block to bad list */
 					if ((rc =
@@ -1204,14 +1210,16 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 							   bb_inode)))
 						continue;
 					write_inode = true;
+#ifdef O_DIRECT
 					fcntl(fileno(dev_ptr), F_SETFL,
 					      flags | O_DIRECT);
+#endif
 
 					/*
-					 * In case we allocated blocks for our 
-					 * addressing structure after our current 
+					 * In case we allocated blocks for our
+					 * addressing structure after our current
 					 * bad block, we need to move our block
-					 * number up so we don't overwrite any 
+					 * number up so we don't overwrite any
 					 * changes we have just done.
 					 */
 					thisblk = MAX(last_allocated, thisblk);
@@ -1219,8 +1227,8 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 			}
 
 			/*
-			 * In case we allocated blocks for the bad block map 
-			 * inode's addressing structure, skip past them so we 
+			 * In case we allocated blocks for the bad block map
+			 * inode's addressing structure, skip past them so we
 			 * don't wipe out our work.
 			 */
 			blkno += nb;
@@ -1235,8 +1243,9 @@ int verify_last_blocks(FILE *dev_ptr, int aggr_block_size,
 			nblocks -= nb;
 		}
 	}
+#ifdef O_DIRECT
 	fcntl(fileno(dev_ptr), F_SETFL, flags);
-
+#endif
 	msg_parms[0] = "100";
 	message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, OSO_MSG);
 	fprintf(stdout, "\n");
