@@ -3,20 +3,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "config.h"
-
+#include <config.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
@@ -50,7 +49,6 @@ unsigned type_jfs;
 char *program_name;
 
 extern int LogOpenMode;
-extern int Is_Device_Mounted(char *);
 FILE *open_by_label(uuid_t, int, int, char *, int *);
 
 static int AGsize;
@@ -69,15 +67,15 @@ char msgstr[MAXSTR];
 #define use_existing_journal 2
 
 /*
- * The following macro defines the initial number of aggregate inodes which 
- * are initialized when a new aggregate is created.  This does not include 
+ * The following macro defines the initial number of aggregate inodes which
+ * are initialized when a new aggregate is created.  This does not include
  * any fileset inodes as those are initialized separately.
  */
 #define INIT_NUM_AGGR_INODES    (BADBLOCK_I + 1)
 
 static struct dinode aggr_inodes[INIT_NUM_AGGR_INODES];
 
-void mkfs_usage()
+void mkfs_usage(void)
 {
 	printf("\nUsage:  %s [-cOqV] [-j log_device] [-J options] "
 	       "[-L vol_label] [-s log_size] device [ blocks ]\n",
@@ -87,8 +85,8 @@ void mkfs_usage()
 	       " -O            Provide case-insensitive support for OS/2 compatability.\n"
 	       " -q            Quiet execution.\n"
 	       " -V            Print version information only.\n"
-	       " -j log_device Set external journal device. (Experimental)\n"
-	       " -J options    Set external journal options. (Experimental)\n"
+	       " -j log_device Set external journal device.\n"
+	       " -J options    Set external journal options.\n"
 	       " -L vol_label  Set volume label for the file system.\n"
 	       " -s log_size   Set log size (in megabytes).\n\n"
 	       "NOTE: -j and -J cannot be used at the same time.\n");
@@ -122,14 +120,14 @@ static int create_fileset(FILE *dev_ptr, int aggr_block_size,
 	/*
 	 * Find space for the inode allocation map page
 	 *
-	 * Also find the fileset inode map location on disk (inode_map_loc).  
-	 * We need to know this in order to initialize the fileset inodes 
+	 * Also find the fileset inode map location on disk (inode_map_loc).
+	 * We need to know this in order to initialize the fileset inodes
 	 * with the proper iag value.
 	 *
-	 * Since we only have one fileset per aggregate in the first release, 
-	 * we always know where the inode map will start.  Therefore, currently 
-	 * we use a hard-coded value.  When we add multiple filesets per 
-	 * aggregate this will need to be modified to find the space for the 
+	 * Since we only have one fileset per aggregate in the first release,
+	 * we always know where the inode map will start.  Therefore, currently
+	 * we use a hard-coded value.  When we add multiple filesets per
+	 * aggregate this will need to be modified to find the space for the
 	 * inode map by looking in the block allocation map for available space.
 	 */
 	inode_map_size = SIZE_OF_MAP_PAGE << 1;
@@ -203,8 +201,8 @@ static int create_aggregate(FILE *dev_ptr,
 			    unsigned type_jfs,
 			    char *logdev,
 			    int64_t logloc,
-			    int logsize, 
-			    bool verify_blocks, 
+			    int logsize,
+			    bool verify_blocks,
 			    uuid_t log_uuid)
 {
 	struct superblock aggr_superblock;
@@ -225,8 +223,8 @@ static int create_aggregate(FILE *dev_ptr,
 
 	/*
 	 * Find where fsck working space will live on disk and mark those
-	 * blocks.  The fsck working space is always at the very end of the 
-	 * aggregate so once we know how big it is we can back up from the 
+	 * blocks.  The fsck working space is always at the very end of the
+	 * aggregate so once we know how big it is we can back up from the
 	 * end to determine where it needs to start.
 	 *
 	 * Need enough 4k pages to cover:
@@ -242,7 +240,7 @@ static int create_aggregate(FILE *dev_ptr,
 	fsck_svclog_length = (50 << L2PSIZE) / aggr_block_size;
 
 	/*
-	 * Now we want the fsck working space to be ignored as actually being 
+	 * Now we want the fsck working space to be ignored as actually being
 	 * part of the filesystem
 	 */
 	number_of_blocks -= fsck_wspace_length;
@@ -279,10 +277,10 @@ static int create_aggregate(FILE *dev_ptr,
 		return rc;
 
 	/*
-	 * In case mkfs does not complete, but we have an old superblock 
-	 * already on this device, we will zero the superblock disk blocks at 
-	 * the beginning and then write the real superblock to disk last.  
-	 * (This keeps the device from appearing to have a complete filesystem 
+	 * In case mkfs does not complete, but we have an old superblock
+	 * already on this device, we will zero the superblock disk blocks at
+	 * the beginning and then write the real superblock to disk last.
+	 * (This keeps the device from appearing to have a complete filesystem
 	 * when initialization is not complete.)
 	 */
 	rc = ujfs_rw_diskblocks(dev_ptr, SUPER1_OFF, SIZE_OF_SUPER, buffer,
@@ -342,14 +340,14 @@ static int create_aggregate(FILE *dev_ptr,
 	/*
 	 * Now initialize the secondary aggregate inode table and map
 	 *
-	 * We can use the same aggr_inodes we already initialized except for 
+	 * We can use the same aggr_inodes we already initialized except for
 	 * the aggregate self inode.  This will be updated by the call to
-	 * init_aggr_inode_table() to point to the secondary table instead of 
+	 * init_aggr_inode_table() to point to the secondary table instead of
 	 * the primary table.
 	 *
-	 * First we need to determine the location; it will follow the block 
-	 * map.  Since the block map might be sparse we need to use the number 
-	 * of blocks instead of the length of the extents.  This works since 
+	 * First we need to determine the location; it will follow the block
+	 * map.  Since the block map might be sparse we need to use the number
+	 * of blocks instead of the length of the extents.  This works since
 	 * the extents are in the inode for mkfs
 	 */
 	inode_map_dscr =
@@ -396,8 +394,8 @@ static int create_aggregate(FILE *dev_ptr,
 	 * Now we will create a fileset as necessary.
 	 *
 	 * Determine the end of the metadata written for the aggregate to tell
-	 * where to put the fileset to be created.  Since the secondary 
-	 * aggregate inode table is the last thing written to the aggregate, 
+	 * where to put the fileset to be created.  Since the secondary
+	 * aggregate inode table is the last thing written to the aggregate,
 	 * the fileset will start following it.
 	 */
 	rc = create_fileset(dev_ptr, aggr_block_size, secondary_ait_end,
@@ -431,8 +429,8 @@ static int create_aggregate(FILE *dev_ptr,
 	 * If we are supposed to verify all blocks, now is the time to do it
 	 *
 	 * First we tell the LVM to stop doing Bad Block Relocation so we can
-	 * catch (and record) any bad blocks ourselves.  Next we run through 
-	 * the available file system space looking for bad blocks.  Finally 
+	 * catch (and record) any bad blocks ourselves.  Next we run through
+	 * the available file system space looking for bad blocks.  Finally
 	 * we tell the LVM to go back to doing Bad Block Relocation.
 	 */
 	PXDaddress(&(aggr_inodes[BADBLOCK_I].di_ixpxd),
@@ -550,7 +548,7 @@ static int create_aggregate(FILE *dev_ptr,
 /*--------------------------------------------------------------------
  * NAME: parse_journal_opts
  *
- * FUNCTION: parse journal (-J) options 
+ * FUNCTION: parse journal (-J) options
  *               set log device name (global logdev)
  *               set appropriate external journal flag
  *
@@ -584,9 +582,9 @@ void parse_journal_opts(const char *opts, int *ext_journal_opt,
 				    open_by_label(log_uuid, 0, 1,
 						  journal_device, &in_use);
 				/*
-				 * If successful, open_by_label returns a file 
-				 * descriptor to an open file.  For jfs_mkfs 
-				 * purposes, we do not yet need that file to be 
+				 * If successful, open_by_label returns a file
+				 * descriptor to an open file.  For jfs_mkfs
+				 * purposes, we do not yet need that file to be
 				 * open, so close it here.
 				 */
 				if (log_fd == NULL) {
@@ -665,16 +663,15 @@ int main(int argc, char *argv[])
 	int c;
 	int l2absize;
 	char *device_name = NULL;
-	char *argp;
 	int rc = 0;
         char volume_label[16] = { "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0" };
 	int64_t number_of_bytes = 0, bytes_on_device;
-	int64_t number_of_blocks, logloc = 0, logsize_in_bytes = 0;
+	int64_t number_of_blocks = 0, logloc = 0, logsize_in_bytes = 0;
 	int64_t requested_blocks = 0;
 	char logdev[255] = { '\0' };	/* Need to use a macro for this size */
 	int aggr_block_size = PSIZE;	/* 4096 */
 	int phys_block_size = PBSIZE, logsize = 0;
-	FILE *dev_handle;
+	FILE *dev_handle = NULL;
 	unsigned type_commit = JFS_GROUPCOMMIT;
 	bool verify_blocks = false;
 	bool no_questions_asked = false;
@@ -685,9 +682,9 @@ int main(int argc, char *argv[])
 
 	if (argc && **argv)
 		program_name = *argv;
-	else 
+	else
 		program_name = "jfs_mkfs";
-		
+
 	printf("%s version %s, %s\n", program_name, VERSION, JFSUTILS_DATE);
 
 	type_jfs = JFS_LINUX | JFS_DIR_INDEX;
@@ -829,7 +826,7 @@ int main(int argc, char *argv[])
 
 	if (aggr_block_size < phys_block_size) {
 		/*
-		 * Make sure the aggr_block_size is not smaller than the 
+		 * Make sure the aggr_block_size is not smaller than the
 		 * logical volume block size.
 		 */
 		sprintf(msgstr, "%d", aggr_block_size);
@@ -871,10 +868,10 @@ int main(int argc, char *argv[])
 
 	    /*
 	     * Make sure we have at least MINJFS for our file system
-	     * Notes: The operating system takes some of the bytes from the 
-	     * partition to use for its own information.  The end user is not 
-	     * aware of this space, so we want to compare a posted minimum 
-	     * size to the actual size of the partition, not just the space 
+	     * Notes: The operating system takes some of the bytes from the
+	     * partition to use for its own information.  The end user is not
+	     * aware of this space, so we want to compare a posted minimum
+	     * size to the actual size of the partition, not just the space
 	     * available for our use.
 	     */
 	    if (number_of_bytes < MINJFS) {
@@ -941,15 +938,15 @@ int main(int argc, char *argv[])
 	/*
 	 * Create journal log for aggregate to use
 	 *
-	 * For the prototype we will only create a journal log if one was 
-	 * specified on the command line.  Eventually we will always need one 
+	 * For the prototype we will only create a journal log if one was
+	 * specified on the command line.  Eventually we will always need one
 	 * and we will need a default method of finding and creating the log.
 	 */
 	if (logdev[0] != '\0') {
 		FILE *fp;
 
 format_journal:
-		/* A log device was specified on the command line.  Call 
+		/* A log device was specified on the command line.  Call
 		   * jfs_logform() to initialize the log */
 		fp = fopen_excl(logdev, "r+");
 		if (fp == NULL) {
@@ -957,7 +954,7 @@ format_journal:
 			fclose(dev_handle);
 			return -1;
 		}
-		/* 
+		/*
 		 * If the user specified logging to an existing external
 		 * journal device, find it and validate its superblock.
 		 */
@@ -986,8 +983,8 @@ format_journal:
 			/* create new external journal device */
 			uuid_clear(log_uuid);
 			/*
-			 * If a volume label has been specified and we're only 
-			 * creating an external journal, apply the label to the 
+			 * If a volume label has been specified and we're only
+			 * creating an external journal, apply the label to the
 			 * external journal.
 			 */
 			if ((ext_journal_opt == create_journal_only)
@@ -1003,20 +1000,20 @@ format_journal:
 		if (rc != 0) {
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			DBG_ERROR(("Internal error: Format failed rc=%x\n", rc))
-			    fclose(dev_handle);
+			if (dev_handle)
+				fclose(dev_handle);
 			return (rc);
 		} else if (ext_journal_opt == create_journal_only) {
 			printf
 			    ("\nJFS external journal created SUCCESSFULLY on %s.\n",
 			     logdev);
-			fclose(dev_handle);
 			return (rc);
 		}
 	} else {
 		type_jfs |= JFS_INLINELOG;
 		if (logsize == 0) {
-			/* If no size specified, let's default to .4 of 
-			 * aggregate size; Which for simplicity is 
+			/* If no size specified, let's default to .4 of
+			 * aggregate size; Which for simplicity is
 			 * 4/1024 == 2**2/2**10 == 1/2**8 == >> 8
 			 *
 			 * Round logsize up to a megabyte boundary */
